@@ -55,10 +55,10 @@ class TestSimulatorHandler:
         s.start("p", "w")
 
         e = BatsimEventAPI.get_notify_no_more_static_job_to_submit(10)
-        msg = BatsimMessage(10.999, [NotifyBatsimEvent(10.999, e['data'])])
+        msg = BatsimMessage(10.00199, [NotifyBatsimEvent(10.00199, e['data'])])
         mocker.patch.object(protocol.NetworkHandler, 'recv', return_value=msg)
         s.proceed_time()
-        assert s.current_time == 10.
+        assert s.current_time == 10
 
     def test_batsim_not_found_must_raise(self, mocker):
         mocker.patch("batsim_py.simulator.which", return_value=None)
@@ -171,7 +171,7 @@ class TestSimulatorHandler:
         s = SimulatorHandler()
         s.start("p", "w", simulation_time=100)
         batsim_py.simulator.CallMeLaterBatsimRequest.assert_called_once_with(  # type: ignore
-            0, 100)
+            0, 100+0.09)
 
     def test_start_must_dispatch_event(self):
         def foo(h: SimulatorHandler): self.__called = True
@@ -277,7 +277,8 @@ class TestSimulatorHandler:
         msg = BatsimMessage(50, [SimulationEndsBatsimEvent(50)])
         mocker.patch.object(protocol.NetworkHandler, 'recv', return_value=msg)
         s.proceed_time(50)
-        simulator.SimulatorHandler.set_callback.assert_called_once()
+        simulator.SimulatorHandler.set_callback.assert_called_once_with(
+            50, mocker.ANY)
 
     def test_proceed_time_with_submitter_finished_without_external_events_must_not_allow_callback(self, mocker):
         s = SimulatorHandler()
@@ -405,7 +406,7 @@ class TestSimulatorHandler:
         s.start("p", "w")
         s.set_callback(50, foo)
         simulator.CallMeLaterBatsimRequest.assert_called_once_with(  # type: ignore
-            0, 50)
+            0, 50+0.09)
 
     def test_queue(self, mocker):
         s = SimulatorHandler()
